==> generator-gitbook-base-0.0.2.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var yeoman = require('yeoman-generator');
var chalk = require('chalk');


var GitbookBaseGenerator = yeoman.generators.Base.extend({
  init: function () {
    this.pkg = require('../package.json');

    this.on('end', function () {
      if (!this.options['skip-install']) {
        this.installDependencies();
      }
    });
  },

  askFor: function () {
    var done = this.async();

    // have Yeoman greet the user
    this.log(this.yeoman);

    // replace it with a short and sweet description of your generator
    this.log(chalk.magenta('You\'re using the fantastic GitbookBase generator.'));

    var prompts = [{
      type: 'confirm',
      name: 'github',
      message: 'Will you be serving on github?',
      default: true
    },
    {
      name:'bookname',
      message:'What would you like to name your gitbook',
      default:true
    },
    { name:'github_repo',
      message:'What is the name of your github repo',
      default:false
    },
    { name:'github_user',
      message:'What is your github username?',
      default:false
    }];

    this.prompt(prompts, function (props) {
      this.github = props.github;
      this.bookname = props.bookname;
      this.mkdir('section1');
      this.mkdir('section2');
      this.mkdir('section3');
      this.mkdir(this.bookname);
      this.copy('_Gruntfile.js', 'Gruntfile.js');
      this.copy('_package.json', 'package.json');
      this.copy('_README.md', this.bookname + '/README.md');
      this.copy('_SUMMARY.md', this.bookname + '/SUMMARY.md');
      this.copy('_page.md', this.bookname + '/section1/README.md');
      this.copy('_page.md', this.bookname + '/section1/page1.md');
      this.copy('_page.md', this.bookname + '/section1/page2.md');
      this.copy('_page.md', this.bookname + '/section1/page3.md');
      this.copy('_page.md', this.bookname + '/section2/README.md');
      this.copy('_page.md', this.bookname + '/section2/page1.md');
      this.copy('_page.md', this.bookname + '/section2/page2.md');
      this.copy('_page.md', this.bookname + '/section3/README.md');
      this.copy('_page.md', this.bookname + '/section3/page3.md');

      done();
    }.bind(this));
  },

  app: function () {
    this.mkdir('app');
    this.mkdir('app/templates');

    this.copy('_package.json', 'package.json');
    this.copy('_bower.json', 'bower.json');
  },

  projectfiles: function () {
    this.copy('editorconfig', '.editorconfig');
    this.copy('jshintrc', '.jshintrc');
  }
});

module.exports = GitbookBaseGenerator;

==> generator-gitbook-base-0.0.4.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var yeoman = require('yeoman-generator');
var chalk = require('chalk');


var GitbookBaseGenerator = yeoman.generators.Base.extend({
  init: function () {
    this.pkg = require('../package.json');

    this.on('end', function () {
      if (!this.options['skip-install']) {
        this.installDependencies();
      }
    });
  },

  askFor: function () {
    var done = this.async();

    // have Yeoman greet the user
    this.log(this.yeoman);

    // replace it with a short and sweet description of your generator
    this.log(chalk.magenta('You\'re using the fantastic GitbookBase generator.'));

    var prompts = [{
      type: 'confirm',
      name: 'github',
      message: 'Will you be serving on github?',
      default: true
    },
    {
      name:'bookname',
      message:'What would you like to name your gitbook',
      default:true
    },
    { name:'github_repo',
      message:'What is the name of your github repo',
      default:false
    },
    { name:'github_user',
      message:'What is your github username?',
      default:false
    }];

    this.prompt(prompts, function (props) {
      this.github = props.github;
      this.name = props.bookname;
      this.mkdir('section1');
      this.mkdir('section2');
      this.mkdir('section3');
      this.mkdir(this.name);
      this.copy('_Gruntfile.js', 'Gruntfile.js');
      this.copy('_package.json', 'package.json');
      this.copy('_README.md', this.bookname + '/README.md');
      this.copy('_SUMMARY.md', this.bookname + '/SUMMARY.md');
      this.copy('_page.md', this.bookname + '/section1/README.md');
      this.copy('_page.md', this.bookname + '/section1/page1.md');
      this.copy('_page.md', this.bookname + '/section1/page2.md');
      this.copy('_page.md', this.bookname + '/section1/page3.md');
      this.copy('_page.md', this.bookname + '/section2/README.md');
      this.copy('_page.md', this.bookname + '/section2/page1.md');
      this.copy('_page.md', this.bookname + '/section2/page2.md');
      this.copy('_page.md', this.bookname + '/section3/README.md');
      this.copy('_page.md', this.bookname + '/section3/page3.md');

      done();
    }.bind(this));
  },

  app: function () {
    this.mkdir('app');
    this.mkdir('app/templates');

    this.copy('_package.json', 'package.json');
    this.copy('_bower.json', 'bower.json');
  },

  projectfiles: function () {
    this.copy('editorconfig', '.editorconfig');
    this.copy('jshintrc', '.jshintrc');
  }
});

module.exports = GitbookBaseGenerator;
